@@ -7,8 +7,8 @@
 #include "mpvcontroller.h"
 #include "mpvcontroller_p.h"
 
+#include <QStandardPaths>
 #include <QVariant>
-#include <QDebug>
 
 #include <clocale>
 
@@ -185,6 +185,10 @@ void MpvController::init()
     mpv_set_wakeup_callback(d_ptr->m_mpv, MpvController::mpvEvents, this);
 
     // otherwise mpv opens a separate window
+    QString configPath = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation);
+    configPath.append(QStringLiteral("/mpvqt"));
+    configPath.append(QStringLiteral("/mpvqt.conf"));
+    setProperty(QStringLiteral("include"), configPath);
     setProperty(QStringLiteral("vo"), QStringLiteral("libmpv"));
 }
 
@@ -297,9 +301,14 @@ mpv_handle *MpvController::mpv() const
     return d_ptr->m_mpv;
 }
 
-void MpvController::observeProperty(const QString &property, mpv_format format)
+void MpvController::observeProperty(const QString &property, mpv_format format, uint64_t id)
 {
-    mpv_observe_property(mpv(), 0, property.toUtf8().data(), format);
+    mpv_observe_property(mpv(), id, property.toUtf8().data(), format);
+}
+
+int MpvController::unobserveProperty(uint64_t id)
+{
+    return mpv_unobserve_property(mpv(), id);
 }
 
 int MpvController::setProperty(const QString &property, const QVariant &value)
